==> haskell-pcre-heavy-1.0.0.3-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pcre-heavy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pcre-heavy
version:              1.0.0.3
visibility:           public
id:                   pcre-heavy-1.0.0.3-AaccQA7uphw78tTmqk8YbP
key:                  pcre-heavy-1.0.0.3-AaccQA7uphw78tTmqk8YbP
license:              LicenseRef-PublicDomain
copyright:            2015-2022 Val Packett <val@packett.cool>
maintainer:           val@packett.cool
author:               Val Packett
homepage:             https://codeberg.org/valpackett/pcre-heavy
synopsis:
    A regexp (regex) library on top of pcre-light you can actually use.

description:
    A regular expressions library that does not suck.
    Based on <https://hackage.haskell.org/package/pcre-light pcre-light>.
    Takes and returns <https://hackage.haskell.org/package/stringable Stringables> everywhere.
    Includes a QuasiQuoter for regexps that does compile time checking.
    SEARCHES FOR MULTIPLE MATCHES! DOES REPLACEMENT!

category:             Web
abi:                  645b7e4dab3efecc4ca1994f2fc6200a
exposed:              True
exposed-modules:      Text.Regex.PCRE.Heavy
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pcre-heavy-1.0.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pcre-heavy-1.0.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pcre-heavy-1.0.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pcre-heavy
hs-libraries:         HSpcre-heavy-1.0.0.3-AaccQA7uphw78tTmqk8YbP
depends:
    base-4.17.2.1 base-compat-0.12.3-H9qTMlLoDHsHlMi1O3x7Rp
    bytestring-0.11.5.3 pcre-light-0.4.1.3-KNdIDQJBMfqZw80tRO96W
    string-conversions-0.4.0.1-GnvCZkNkYXZBEsxBCPZYSp
    template-haskell-2.19.0.0

haddock-interfaces:   /usr/share/doc/haskell-pcre-heavy/html/pcre-heavy.haddock
haddock-html:         /usr/share/doc/haskell-pcre-heavy/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pcre-heavy-1.0.0.4-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pcre-heavy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pcre-heavy
version:              1.0.0.4
visibility:           public
id:                   pcre-heavy-1.0.0.4-J3hkQjLgczdJIHZh8cnpYM
key:                  pcre-heavy-1.0.0.4-J3hkQjLgczdJIHZh8cnpYM
license:              LicenseRef-PublicDomain
copyright:            2015-2025 Val Packett <val@packett.cool>
maintainer:           val@packett.cool
author:               Val Packett
homepage:             https://codeberg.org/valpackett/pcre-heavy
synopsis:
    A regexp (regex) library on top of pcre-light you can actually use.

description:
    A PCRE-based regular expressions library with support for multiple matches and replacements.
    Based on <https://hackage.haskell.org/package/pcre-light pcre-light>.
    Takes and returns <https://hackage.haskell.org/package/string-conversions convertible strings> everywhere.
    Includes a QuasiQuoter for regexps that does compile time checking.

category:             Web
abi:                  d037adf062a7ba1de2c2abfa9da50b64
exposed:              True
exposed-modules:      Text.Regex.PCRE.Heavy
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pcre-heavy-1.0.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pcre-heavy-1.0.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pcre-heavy-1.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pcre-heavy
hs-libraries:         HSpcre-heavy-1.0.0.4-J3hkQjLgczdJIHZh8cnpYM
depends:
    base-4.17.2.1 base-compat-0.12.3-H9qTMlLoDHsHlMi1O3x7Rp
    bytestring-0.11.5.3 pcre-light-0.4.1.3-KNdIDQJBMfqZw80tRO96W
    string-conversions-0.4.0.1-GnvCZkNkYXZBEsxBCPZYSp
    template-haskell-2.19.0.0

haddock-interfaces:   /usr/share/doc/haskell-pcre-heavy/html/pcre-heavy.haddock
haddock-html:         /usr/share/doc/haskell-pcre-heavy/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
